Search Opinions
Author: Opinions/Memorandum Decisions
Description: AZ Supreme Court
Keywords: ,DotNetNuke,DNN

# Arizona Judicial Branch

Skip to main navigation | Skip to main content | Skip to footer navigation

## Opinions/Memorandum Decisions

Search Opinions/Memo Decs

Search filter ON - Top 1000 records found Clear search filter Court: Court of Appeals, Div 1 | Search Decisions

1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | ...
|  | 2/13/2014 |  | 1 CA-CR 12-0066 | STATE v. WILLIAMS | MEMORANDUM
| Patricia A. Orozco, Author; Randall M. Howe, Concur; Samuel A. Thumma, Concur
|  | 2/13/2014 |  | 1 CA-CR 13-0005 | STATE v. CLEMENTS | MEMORANDUM
| Samuel A. Thumma, Author; Randall M. Howe, Concur; Patricia A. Orozco, Concur
|  | 2/13/2014 |  | 1 CA-CR 13-0161 | STATE v. WALLS | MEMORANDUM
| Patricia A. Orozco, Author; Randall M. Howe, Concur; Samuel A. Thumma, Concur
|  | 2/13/2014 |  | 1 CA-CV 11-0339 | LERNER v. DMB/CURRIER | OPINION
| Diane M. Johnsen, Author; Donn Kessler, Concur; Jon W. Thompson, Concur in part; Dissent in part
| 1. May a seller of a home be liable to a buyer for failing to disclose a material fact concerning the home if the buyer cannot reasonably discover the material fact for himself/herself? 2. Arizona Revised Statutes ("A.R.S.") section 32-2156(A)(3) bars a claim against a seller "of real property for failing to disclose that the property being transferred . . . is or has been . . . located in the vicinity of a sex offender." Is the statute unconstitutional under the anti-abrogation clause of the Arizona Constitution, Art. 18, Section 6?
|  | 2/13/2014 |  | 1 CA-CV 12-0477 | LARSON v. UNITED | MEMORANDUM
| Samuel A. Thumma, Author; Randall M. Howe, Concur; Patricia A. Orozco, Concur
|  | 2/13/2014 |  | 1 CA-CV 12-0740 | ESTATE v. RECOVERY et al. | OPINION
| Patricia K. Norris, Author; Peter B. Swann, Concur; Samuel A. Thumma, Concur
| Does Part C of the Medicare Act and its associated regulations preempt Arizona’s anti-subrogation doctrine so that a Medicare Advantage plan may recover the medical expenses it paid for one of its enrollees from the settlement of personal injury claims asserted on behalf of the enrollee?
|  | 2/13/2014 |  | 1 CA-CV 13-0049 | BANKS v. NOWLIN | MEMORANDUM
| Jon W. Thompson, Author; Lawrence F. Winthrop, Concur; Margaret H. Downie, Concur
|  | 2/13/2014 |  | 1 CA-CV 13-0163 | EDWARDS v. FIRST AMERICAN | MEMORANDUM
| John C. Gemmill, Author; Samuel A. Thumma, Concur; Randall M. Howe, Concur
|  | 2/13/2014 |  | 1 CA-IC 12-0074 | WOOD v. FRY'S/SEDGWICK | MEMORANDUM
| Jon W. Thompson, Author; Lawrence F. Winthrop, Concur; Margaret H. Downie, Concur
|  | 2/13/2014 |  | 1 CA-JV 13-0265 | JEYME P. v. ADES, K.P., I.P. | MEMORANDUM
| Kent E. Cattani, Author; Margaret H. Downie, Concur; Michael J. Brown, Concur
1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | ...

Search Decision Document Text